@@ -143,6 +143,8 @@ for dir in dirlist:
       gid = set([])
       cursor.execute("SELECT title,codeaccess,tg.cn FROM jos_tool_version AS tv, jos_tool_groups AS tg WHERE tg.toolid=tv.toolid AND tv.toolname='" + id + "' AND state='3' AND (tg.role=1 or tg.role=2)")
       rows = cursor.fetchall()
+      if len(rows) == 0:
+        continue
       name = id
       for name,sourcepublic,gidref in rows:
         if (sourcepublic == '@OPEN'):
